==> cdktf-0.9.0.dev6.tar.gz: package/lib/terraform-module.d.ts <==
import { Construct } from "constructs";
import { TerraformElement } from "./terraform-element";
import { TerraformProvider } from "./terraform-provider";
import { ITerraformDependable } from "./terraform-dependable";
/**
 * @experimental
 */
export interface TerraformModuleOptions {
    /**
     * @experimental
     */
    readonly source: string;
    /**
     * @experimental
     */
    readonly version?: string;
    /**
     * @experimental
     */
    readonly providers?: (TerraformProvider | TerraformModuleProvider)[];
    /**
     * @experimental
     */
    readonly dependsOn?: ITerraformDependable[];
}
/**
 * @experimental
 */
export interface TerraformModuleProvider {
    /**
     * @experimental
     */
    readonly provider: TerraformProvider;
    /**
     * @experimental
     */
    readonly moduleAlias: string;
}
/**
 * @experimental
 */
export declare abstract class TerraformModule extends TerraformElement implements ITerraformDependable {
    /**
     * @experimental
     */
    readonly source: string;
    /**
     * @experimental
     */
    readonly version?: string;
    private _providers?;
    /**
     * @experimental
     */
    dependsOn?: string[];
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, options: TerraformModuleOptions);
    /**
     * @experimental
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    /**
     * @experimental
     */
    interpolationForOutput(moduleOutput: string): string;
    /**
     * @experimental
     */
    get fqn(): string;
    /**
     * @experimental
     */
    get providers(): (TerraformProvider | TerraformModuleProvider)[] | undefined;
    /**
     * @experimental
     */
    addProvider(provider: TerraformProvider | TerraformModuleProvider): void;
    /**
     * @experimental
     */
    toTerraform(): any;
    /**
     * @experimental
     */
    toMetadata(): any;
    private validateIfProvidersHaveUniqueKeys;
}

==> cdktf-0.17.0.dev18.tar.gz: package/lib/terraform-module.d.ts <==
import { Construct } from "constructs";
import { TerraformElement } from "./terraform-element";
import { TerraformProvider } from "./terraform-provider";
import { ITerraformDependable } from "./terraform-dependable";
import { ITerraformIterator } from "./terraform-iterator";
export interface TerraformModuleUserConfig {
    readonly providers?: (TerraformProvider | TerraformModuleProvider)[];
    readonly dependsOn?: ITerraformDependable[];
    readonly forEach?: ITerraformIterator;
    readonly skipAssetCreationFromLocalModules?: boolean;
}
export interface TerraformModuleConfig extends TerraformModuleUserConfig {
    readonly source: string;
    readonly version?: string;
}
export interface TerraformModuleProvider {
    readonly provider: TerraformProvider;
    readonly moduleAlias: string;
}
export declare abstract class TerraformModule extends TerraformElement implements ITerraformDependable {
    readonly source: string;
    readonly version?: string;
    private _providers?;
    dependsOn?: string[];
    forEach?: ITerraformIterator;
    readonly skipAssetCreationFromLocalModules?: boolean;
    constructor(scope: Construct, id: string, options: TerraformModuleConfig);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    interpolationForOutput(moduleOutput: string): import("./tokens").IResolvable;
    getString(output: string): string;
    get providers(): (TerraformProvider | TerraformModuleProvider)[] | undefined;
    addProvider(provider: TerraformProvider | TerraformModuleProvider): void;
    toTerraform(): any;
    toMetadata(): any;
    private validateIfProvidersHaveUniqueKeys;
}
